package gui;

import java.util.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;

import gui.*;
import gui.dialogs.*;

class MainMenu extends JMenuBar
{
	SimWinMgr simWinMgr;
	JMenuItem miFileNew = new JMenuItem("New");
	JMenuItem miFileOpen = new JMenuItem("Open");
	JMenuItem miFileClose = new JMenuItem("Close");
	JMenuItem miFileExit = new JMenuItem("Exit");
	JCheckBoxMenuItem miOptionsShowStatistics = new JCheckBoxMenuItem("Show Statistics");
	JRadioButtonMenuItem miOptionsPLAFWindows = new JRadioButtonMenuItem("Windows");
	JRadioButtonMenuItem miOptionsPLAFMotif = new JRadioButtonMenuItem("Motif");
	JRadioButtonMenuItem miOptionsPLAFMetal = new JRadioButtonMenuItem("Metal");
	JMenuItem miSimulationStep = new JMenuItem("Step");
	JMenuItem miSimulationGoTo = new JMenuItem("Go to ...");
	JMenuItem miSimulationWindows = new JMenuItem("Windows...");
	JMenuItem miHelpAbout = new JMenuItem("About CellSim");
	JMenuItem miHelpClassHierarchy = new JMenuItem("Class Hierarchy");

	Vector savedOptionsFileNew = null;

	public MainMenu(SimWinMgr swMgr)
	{
		simWinMgr = swMgr;
		MenuItemListener mil = new MenuItemListener();

		JMenu fileMenu = new JMenu("File");
		miFileNew.addActionListener(mil);
		miFileOpen.addActionListener(mil);
		miFileClose.addActionListener(mil);
		miFileExit.addActionListener(mil);
		fileMenu.add(miFileNew);
		fileMenu.add(miFileOpen);
		fileMenu.add(miFileClose);
		fileMenu.add(miFileExit);
		add(fileMenu);

		JMenu optionsMenu = new JMenu("Options");
		miOptionsShowStatistics.addActionListener(mil);
		JMenu optionsPLAFMenu = new JMenu("Look & Feel");
		ButtonGroup bgPLAF = new ButtonGroup();
		miOptionsPLAFWindows.addActionListener(mil);
		miOptionsPLAFMotif.addActionListener(mil);
		miOptionsPLAFMetal.addActionListener(mil);
		optionsPLAFMenu.add(miOptionsPLAFWindows);
		bgPLAF.add(miOptionsPLAFWindows);
		optionsPLAFMenu.add(miOptionsPLAFMotif);
		bgPLAF.add(miOptionsPLAFMotif);
		optionsPLAFMenu.add(miOptionsPLAFMetal);
		bgPLAF.add(miOptionsPLAFMetal);
		optionsMenu.add(miOptionsShowStatistics);
		optionsMenu.addSeparator();
		optionsMenu.add(optionsPLAFMenu);
		add(optionsMenu);

		JMenu simulationMenu = new JMenu("Simulation");
		miSimulationStep.addActionListener(mil);
		miSimulationGoTo.addActionListener(mil);
		miSimulationWindows.addActionListener(mil);
		simulationMenu.add(miSimulationStep);
		simulationMenu.add(miSimulationGoTo);
		simulationMenu.addSeparator();
		simulationMenu.add(miSimulationWindows);
		add(simulationMenu);

		JMenu helpMenu = new JMenu("Help");
		miHelpAbout.addActionListener(mil);
		miHelpClassHierarchy.addActionListener(mil);
		helpMenu.add(miHelpAbout);
		helpMenu.add(miHelpClassHierarchy);
		add(helpMenu);
	}

	class MenuItemListener implements ActionListener
	{
		public void actionPerformed(ActionEvent e)
		{
			JMenuItem menuItem = (JMenuItem)e.getSource();
			if(menuItem == miFileExit)
			{
				if(simWinMgr.exit())
					System.exit(0);
			}
			else if(menuItem == miFileNew)
			{
				FileNewDialog fileNewDialog = new FileNewDialog(simWinMgr);
				Vector retVec = fileNewDialog.getFileNames(savedOptionsFileNew);
				if(retVec != null)
				{
					simWinMgr.createSimulationWindow(retVec);
					savedOptionsFileNew = retVec;
				}
			}
			else if(menuItem == miFileClose)
			{
				simWinMgr.closeCurrentSimulationWindow();
			}
			else if(menuItem == miSimulationStep)
			{
				simWinMgr.nextStep();
			}
/*			else if(menuItem == miOptionsPLAFWindows)
			{
				try {
					UIManager.setLookAndFeel("com.sun.java.swing.plaf.windows.WindowsLookAndFeel");
				} catch(Exception x) {
					System.err.println(x);
				}
			}
			else if(menuItem == miOptionsPLAFMotif)
			{
				try {
					UIManager.setLookAndFeel("com.sun.java.swing.plaf.motif.MotifLookAndFeel");
				} catch(Exception x) {
					System.err.println(x);
				}
			}
			else if(menuItem == miOptionsPLAFMetal)
			{
				try {
					UIManager.setLookAndFeel("javax.swing.plaf.metal.MetalLookAndFeel");
				} catch(Exception x) {
					System.err.println(x);
				}
			}
*/
		}
	}
}
